#!/bin/bash

#  It is recommended to test the script on a local machine for its purpose and effects.
#  ManageEngine Desktop Central will not be responsible for any
#  damage/loss to the data/setup based on the behavior of the script.
#  Description - Script for Catalina Upgrade

#  Parameters - "<SERVERPATH> - Path to the network share(where the file or folder is present)>"
#               Example with username and password - "smb://administrator:password@172.21.201.118/D/" 
#.              Example without username and password - "smb://172.21.201.118/D/" 

#  Configuration Type - COMPUTER

# MacOS Catalina is copyed to the agent Mac machine

SERVERPATH="smb://Administrator:admin@192.168.195.147/D/Srinath/"

mkdir "/private/tmp/sharePoint"
MOUNTPATH="/private/tmp/sharePoint"

COPYPATH="/private/tmp"

FILEORFOLDERNAME="$MOUNTPATH/installCatalina.tar.gz"

mount -t smbfs "$SERVERPATH" "$MOUNTPATH"

cp -R "$FILEORFOLDERNAME" "$COPYPATH"

# MacOS Catalina system comptability check

osvers_minor=$(sw_vers -productVersion | awk -F. '{print $2}')

machine_model=`sysctl hw.model`

machine_model=$(echo $machine_model| cut -d' ' -f 2)

if [[ ${osvers_minor} -gt 8 ]];then
    
    if [[ ${osvers_minor} -lt 15 ]];then
        
        if [[ $machine_model = *"MacBookPro"* ]];then
            
            machine_model_number=$(echo $machine_model| cut -d',' -f 1)
            
            machine_model_number=${machine_model_number:10:2}
            
            if [ $machine_model_number -lt "9" ];then
            
                echo "Catalina is not compatible to your machine. As your MacBookPro model is $machine_model and it should be minimum of MacBookPro9,2"
                
                exit 1;
                
            fi
            
        elif [[ $machine_model = *"MacBookAir"* ]];then
            
            machine_model_number=$(echo $machine_model| cut -d',' -f 1)
            
            machine_model_number=${machine_model_number:10:2}
            
            if [ $machine_model_number -lt "5" ];then
                
                echo "Catalina is not compatible to your machine. As your MacBookAir model is $machine_model and it should be minimum of MacBookAir5,1"
                
                exit 1;
                
            fi

        elif [[ $machine_model = *"MacBook"* ]];then

            machine_model_number=$(echo $machine_model| cut -d',' -f 1)

            machine_model_number=${machine_model_number:7:2}

            if [ $machine_model_number -lt "8" ];then
            
                echo "Catalina is not compatible to your machine. As your MacBook model is $machine_model and it should be minimum of MacBook8,1"

                exit 1;

            fi

            
        elif [[ $machine_model = *"iMacPro"* ]];then
            
            machine_model_number=$(echo $machine_model| cut -d',' -f 1)
            
            machine_model_number=${machine_model_number:7:2}
            
            if [ $machine_model_number -lt "1" ];then
            
                echo "Catalina is not compatible to your machine. As your iMacPro model is $machine_model and it should be minimum of imacPro1,1"
                
                exit 1;
                
            fi

        elif [[ $machine_model = *"iMac"* ]];then

            machine_model_number=$(echo $machine_model| cut -d',' -f 1)

            machine_model_number=${machine_model_number:4:2}

            if [ $machine_model_number -lt "13" ];then
            
                echo "Catalina is not compatible to your machine. As your iMac model is $machine_model and it should be minimum of iMac13,1"

                exit 1;

            fi

        elif [[ $machine_model = *"Macmini"* ]];then
            
            machine_model_number=$(echo $machine_model| cut -d',' -f 1)
            
            machine_model_number=${machine_model_number:7:2}
            
            if [ $machine_model_number -lt "6" ];then
            
                echo "Catalina is not compatible to your machine. As your MacMini model is $machine_model and it should be minimum of MacMini6,1"
                
                exit 1;
                
            fi
            
        elif [[ $machine_model = *"MacPro"* ]];then
            
            machine_model_number=$(echo $machine_model| cut -d',' -f 1)
            
            machine_model_number=${machine_model_number:6:2}
            
            if [ $machine_model_number -lt "6" ];then
            
                echo "Catalina is not compatible to your machine. As your MacPro model is $machine_model and it should be minimum of MacPro6,1"
                
                exit 1;
                
            fi
            
        fi
        
    else
    
        echo "macOS Catalina is already installed"
        
        exit 0;
        
    fi
    
else
    
    echo "macOS Catalina can't be installed in this machine. The minimum OS requred is 10.8"
    exit 1;
    
fi

# MacOS Catalina Installation

tar -xzf /private/tmp/installCatalina.tar.gz -C /private/tmp

osascript -e 'tell app "Finder" to display dialog "Your OS will be upgraded to Catalina. System restarts in 5 minutes. Kindly save your data."'

filename=/private/tmp/Install\ macOS\ Catalina.app

filesize=`du -hs "$filename"`

echo $filesize

if [ -e /private/tmp/Install\ macOS\ Catalina.app/Contents/Resources/startosinstall ];then

    echo "./Install macOS Catalina.app/Contents/Resources/startosinstall executable exists"

else
    
    echo "./Install macOS Catalina.app/Contents/Resources/startosinstall executable doesnot exists"
    
    exit 1;

fi

./Install\ macOS\ Catalina.app/Contents/Resources/startosinstall --volume / --rebootdelay 300 --nointeraction

umount "$MOUNTPATH"
rm -R "$MOUNTPATH"

exit 0
